==> calligra-2.4.3.tar.xz: calligra-2.4.3/kexi/core/kexitextmsghandler.h <==
/* This file is part of the KDE project
   Copyright (C) 2005 Jarosław Staniek <staniek@kde.org>

   This library is free software; you can redistribute it and/or
   modify it under the terms of the GNU Library General Public
   License as published by the Free Software Foundation; either
   version 2 of the License, or (at your option) any later version.

   This library is distributed in the hope that it will be useful,
   but WITHOUT ANY WARRANTY; without even the implied warranty of
   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
   Library General Public License for more details.

   You should have received a copy of the GNU Library General Public License
   along with this library; see the file COPYING.LIB.  If not, write to
   the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
 * Boston, MA 02110-1301, USA.
*/

#ifndef KEXITXTMSGHANDLER_H
#define KEXITXTMSGHANDLER_H

#include "kexiguimsghandler.h"

//! @short A wrapper that redirects messages to a string variables instead of displaying them.
//! See KexiTextMessageHandler constructor for details.
class KEXICORE_EXPORT KexiTextMessageHandler : public KexiGUIMessageHandler
{
public:
    KexiTextMessageHandler(QString &messageTarget, QString &detailsTarget);
    virtual ~KexiTextMessageHandler();

    using KexiGUIMessageHandler::showMessage;

    virtual void showMessage(MessageType type, const QString &title, const QString &details,
                             const QString& dontShowAgainName = QString());

    QString *m_messageTarget, *m_detailsTarget;
};

#endif

==> calligra_2.7.2.orig.tar.xz: calligra-2.7.2/kexi/core/kexitextmsghandler.h <==
/* This file is part of the KDE project
   Copyright (C) 2004-2013 Jarosław Staniek <staniek@kde.org>

   This library is free software; you can redistribute it and/or
   modify it under the terms of the GNU Library General Public
   License as published by the Free Software Foundation; either
   version 2 of the License, or (at your option) any later version.

   This library is distributed in the hope that it will be useful,
   but WITHOUT ANY WARRANTY; without even the implied warranty of
   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
   Library General Public License for more details.

   You should have received a copy of the GNU Library General Public License
   along with this library; see the file COPYING.LIB.  If not, write to
   the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
 * Boston, MA 02110-1301, USA.
*/

#ifndef KEXITXTMSGHANDLER_H
#define KEXITXTMSGHANDLER_H

#include "kexiguimsghandler.h"

//! @short A wrapper that redirects messages to a string variables instead of displaying them.
//! See KexiTextMessageHandler constructor for details.
class KEXICORE_EXPORT KexiTextMessageHandler : public KexiGUIMessageHandler
{
public:
    KexiTextMessageHandler(QString &messageTarget, QString &detailsTarget);
    virtual ~KexiTextMessageHandler();

    using KexiGUIMessageHandler::showMessage;

protected:
    using KexiGUIMessageHandler::showErrorMessageInternal;

    virtual void showErrorMessageInternal(const QString &title, const QString &details = QString());
    virtual void showMessageInternal(MessageType type, const QString &title, const QString &details,
                                     const QString& dontShowAgainName = QString());

    class Private;
    Private* const d;
};

#endif
